#!/bin/sh

DATE=`date "+%Y%m%d"`
TIME=`date "+%Y%m%d-%H%M%S"`
HOSTNAME=`hostname`
DIR=/root/logs


write_links()
{
	NAME="link-qos"
	FILE=${DIR}/${HOSTNAME}.${NAME}.${DATE}
	
	print_header "links" ${FILE}
	printf "${TIME}" >> $FILE
    echo "/links" | nc localhost 8080 | awk 'NR > 5 {print "\t" $1 "\t" $2 "\t" $4 "\t" $5 "\t" $6}' | tr '\n' '\t;' >> ${FILE}
    printf "\n" >> $FILE

}

write_topo()
{
	NAME="topo"
	FILE=${DIR}/${HOSTNAME}.${NAME}.${DATE}
	
	print_header "topo" ${FILE}
	printf "${TIME}" >> $FILE
    echo "/topo" | nc localhost 8080 | awk 'NR > 5 {print "\t" $1 "\t" $2 "\t" $3 "\t" $4 "\t" $5 "\t" $6}' | tr '\n' '\t' >> ${FILE}
    printf "\n" >> $FILE	
}

write_routing_table()
{
	NAME="routing-table"
	FILE=${DIR}/${HOSTNAME}.${NAME}.${DATE}
	
	print_header "route" ${FILE}
	printf "${TIME}" >> $FILE
    echo "/route" | nc localhost 8080 | awk 'NR > 5 {print "\t" $1 "\t" $2 "\t" $3 "\t" $4 "\t" $5}' | tr '\n' '\t' >> ${FILE}
    printf "\n" >> $FILE	
}

write_hna()
{
	NAME="hna"
	FILE=${DIR}/${HOSTNAME}.${NAME}.${DATE}
	
	print_header "hna" ${FILE}
	printf "${TIME}" >> $FILE
    echo "/hna" | nc localhost 8080 | awk 'NR > 5 {print "\t" $1 "\t" $2}' | tr '\n' '\t' >> ${FILE}
    printf "\n" >> $FILE	
}

write_mid()
{
	NAME="mid"
	FILE=${DIR}/${HOSTNAME}.${NAME}.${DATE}
	
	print_header "mid" ${FILE}
	printf "${TIME}" >> $FILE
    echo "/mid" | nc localhost 8080 | awk 'NR > 5 {print "\t" $1 "\t" $2}' | tr '\n' '\t' >> ${FILE}
    printf "\n" >> $FILE	
}

print_header()
{
	if [ ! -f ${2} ] ; then
		case "${1}" in
			links)
				printf "Link quality log for ${HOSTNAME}\n" > ${2}
	        	printf "Date \t {Local IP \t Remote IP \t LQ \t NLQ \t ETX}*\n" >> ${2}
				;;
			topo)
				printf "Topo log for ${HOSTNAME}\n" > ${2}
        		printf "Date \t {Destination IP \t Last hop IP \t LQ \t NLQ \t Cost}*\n" >> ${2}
				;;
			route)
				printf "Routing table log for ${HOSTNAME}\n" > ${2}
		    	printf "Date \t {Destination IP \t Gateway IP \t Metric \t ETX \t Interface}*\n" >> ${2}
				;;
			hna)
				printf "HNA log for ${HOSTNAME}\n" > ${2}
	    		printf "Date \t {Destination \t Gateway}*\n" >> ${2}
				;;
			mid)
				printf "MID log for ${HOSTNAME}\n" > ${2}
    			printf "Date \t {IP \t Aliases}*\n" >> ${2}
				;;							
			esac
		fi	
}


if [ ! -d ${DIR} ] ; then
        mkdir -p ${DIR}
fi

write_links
write_topo
write_routing_table
write_hna
write_mid


